#include "car_player.hpp"
#include "utils/player_input.hpp"
#include <godot_cpp/variant/transform3d.hpp>
#include <godot_cpp/classes/physics_direct_body_state3d.hpp>

namespace godot {
void CarPlayer::_bind_methods() {
#define CLASSNAME CarPlayer
}

void CarPlayer::setup_player_input(PlayerInput *input) {
    input->listen_to(PlayerInput::Listener("steer_right", "steer_left", callable_mp(this, &CarPlayer::on_steer)));
    input->listen_to(PlayerInput::Listener("accelerate", callable_mp(this, &CarPlayer::on_accelerate)));
    input->listen_to(PlayerInput::Listener("brake", callable_mp(this, &CarPlayer::on_brake)));
}

void CarPlayer::spawn_at_position(Transform3D const &transform) {
    this->set_transform(transform);
    this->set_scale({1,1,1});
}

void CarPlayer::on_steer(Ref<InputEvent> event, float value) {
    this->set_current_steering(value * this->steering_factor);
}

void CarPlayer::on_brake(Ref<InputEvent> input, float value) {
    this->set_brake(value != 0);
}

void CarPlayer::on_accelerate(Ref<InputEvent> input, float value) {
    this->set_target_speed(max_speed * value);
}

Node *CarPlayer::to_node() { return this; }
}
